# Table of Contents

- [free-draw](<./free-draw.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Free Draw Diagrams](<./Free-Draw-Diagrams.md>)
  - [Creating Free Draw Diagrams](<./Free-Draw-Diagrams/Creating-Free-Draw-Diagrams.md>)
  - [Using Free Draw Diagrams](<./Free-Draw-Diagrams/Using-Free-Draw-Diagrams.md>)
  - [Adding Fact Sheets as Shapes](<./Free-Draw-Diagrams/Adding-Fact-Sheets-as-Shapes.md>)
  - [Linking and Unlinking Fact Sheets to Shapes](<./Free-Draw-Diagrams/Linking-and-Unlinking-Fact-Sheets-to-Shapes.md>)
  - [Changing and Opening Linked Fact Sheets](<./Free-Draw-Diagrams/Changing-and-Opening-Linked-Fact-Sheets.md>)
  - [Creating New Fact Sheets and Relations from Within the Canvas](<./Free-Draw-Diagrams/Creating-New-Fact-Sheets-and-Relations-from-Within-the-Canvas.md>)
  - [Types of Connections Between Fact Sheets](<./Free-Draw-Diagrams/Types-of-Connections-Between-Fact-Sheets.md>)
  - [Expanding Interfaces](<./Free-Draw-Diagrams/Expanding-Interfaces.md>)
  - [Expanding Relations](<./Free-Draw-Diagrams/Expanding-Relations.md>)
  - [Adding Layers](<./Free-Draw-Diagrams/Adding-Layers.md>)
  - [Linking Diagram to Other Diagrams](<./Free-Draw-Diagrams/Linking-Diagram-to-Other-Diagrams.md>)
  - [Selecting Fact Sheets by Filter](<./Free-Draw-Diagrams/Selecting-Fact-Sheets-by-Filter.md>)
  - [Dependencies, Drill-Downs, and Roll-Ups](<./Free-Draw-Diagrams/Dependencies-Drill-Downs-and-Roll-Ups.md>)
  - [Flexible Drill-Down](<./Free-Draw-Diagrams/Flexible-Drill-Down.md>)
  - [Applying Labels](<./Free-Draw-Diagrams/Applying-Labels.md>)
  - [Displaying Relation Labels](<./Free-Draw-Diagrams/Displaying-Relation-Labels.md>)
  - [Applying and Aggregating Views](<./Free-Draw-Diagrams/Applying-and-Aggregating-Views.md>)
  - [Inventory Updates](<./Free-Draw-Diagrams/Inventory-Updates.md>)
  - [Applying Inventory Updates](<./Free-Draw-Diagrams/Applying-Inventory-Updates.md>)
